datastructuretools.ImmutableDictionary
======================================

.. inheritance-diagram:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.clear

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.copy

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.get

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.has_key

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.items

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.iteritems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.iterkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.itervalues

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.keys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.pop

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.popitem

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.setdefault

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.update

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.values

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewitems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.viewvalues

   .. note:: Inherited from `__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__cmp__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__contains__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__delitem__

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__eq__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__ge__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__getitem__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__gt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__iter__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__le__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__len__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__lt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__ne__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__repr__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__setitem__

.. automethod:: abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary.__str__

   .. note:: Inherited from `__builtin__.object`
